extensions [matrix]


turtles-own [
  liste_croyance            ;liste des croyances au cours du temps
  liste_performence         ;liste des performences au cours du temps
  liste_ind_nature          ;liste des indices naturels  au cours du temps représentant la qualité d'énquête
                            ;cette liste suit une gaussienne de moyenne parametre_a_estimer
  liste_estime_direct       ;propre fondement sur l'estimation du paramètre

  liste_conf_epist          ;liste des confiances épistémiques que possèdent un agent envers les autres agents

  expert                    ;renseigne si l'agent est expert ou non 1=expert 0=layman
  x-pos                     ;position x de l'agent
  y-pos                     ;position y de l'agent

  indegree                  ; la somme des poids de liens de confiance pointant vers l'agent
  nb_out_neighboors         ; le nombre de voisins auprès desquels l'agent recueille de l'info
  couple                     ; le couple (dernière perf , nb_out_neighboors)
]

globals [
  list_perf_glob            ;liste des performences globales au cours du temps
  list_perf_expert          ;liste des performences globales des experts au cours du temps
  list_perf_lay             ;liste des performences globales des laymans au cours du temps
  matrice                   ; la matrice du graphe de confiance sour forme de liste des ligne de la matrice
  matrix                    ; la matrice du graphe de confiance sous forme d'objet 'matrix' (extension spéciale)
  coeff_matrix                       ; une valeur pour montrer comment récupérer une cellul
]

to setup
  clear-all
  if ecart_type_expert >= ecart_type_laymen
  [
    clear-output
    output-write "problème d'initialisation des paramètres d'écart-type"
    stop
  ]

  if (number_of_agents < 2) or (number_of_agents > 1000)
  [
    clear-output
    output-write "Le nombre d'agents doit être compris entre 2 et 1000"
    stop
  ]

  random-seed seed-random
  create_turtles
  init
  init_conf_epist
  add_arrow
  set-up-matrice

  reset-ticks
end




;création des agents
to create_turtles
  let nb_expert ( (round ( proportion_expert * number_of_agents) ) - 1 )
  let nb_tortue number_of_agents

  create-turtles 1
  [
    set x-pos 0 set y-pos 0
    ifelse agent1_expert
    [ set expert true
      set nb_tortue (nb_tortue - 1 )
      set nb_expert (nb_expert - 1 ) ]
    [ set expert false
      set nb_tortue (nb_tortue - 1 ) ]
    ifelse expert
    [ set color blue ]
    [ set color red ]
    set shape "circle"
  ]

  let nb (number_of_agents - 1)
  let radius 20
  let start_radian 0
  let increment_angle (360 / nb)
  let increment_radian (increment_angle * pi)

  while [nb != 0]
  [
    let x (sin(start_radian) * radius)
    let y (cos(start_radian) * radius)
   create-turtles 1
   [
      set x-pos x set y-pos y
      setxy x-pos y-pos
      ifelse random nb_tortue > nb_expert
      [ set expert false
        set nb_tortue (nb_tortue - 1 ) ]
      [ set expert true
        set nb_tortue (nb_tortue - 1 )
        set nb_expert (nb_expert - 1 ) ]
      ifelse expert
      [ set color blue ]
      [ set color red ]
      set shape "circle"
   ]
   set start_radian (start_radian + increment_radian)
   set nb (nb - 1)
  ]
end



;initialisation des listes des agents
to init
  ask turtles
  [
    set liste_croyance []
    set liste_performence []
    set liste_ind_nature []
    set liste_estime_direct []
    set liste_conf_epist []
    set indegree 0

    set liste_croyance lput (random 100 / 100) liste_croyance
    set liste_ind_nature lput (random 100 / 100) liste_ind_nature
  ]

  set list_perf_glob []
  set list_perf_expert []
  set list_perf_lay []
end



;initialisation des confiances entre les agents
to init_conf_epist
  let i 0
  let j 0
  if modeles_relations = "master"
  [
    foreach sort turtles
    [
        set j 0
        foreach sort turtles
        [
            ifelse i = j
            [
              ifelse i = 0
              [ask turtle i [ set liste_conf_epist lput 0 liste_conf_epist] ]
              [ask turtle i [ set liste_conf_epist lput (1 / 2) liste_conf_epist] ]
            ]
            [
              ifelse i = 0
              [ask turtle i [ set liste_conf_epist lput (1 / (number_of_agents - 1) ) liste_conf_epist] ]
              [
                ifelse j = 0
                [ask turtle i [ set liste_conf_epist lput (1 / 2) liste_conf_epist] ]
                [ask turtle i [ set liste_conf_epist lput 0 liste_conf_epist] ]
              ]
            ]
            set j (j + 1)
         ]
        set i (i + 1)

    ]
  ]
  if modeles_relations = "circle"
  [
    foreach sort turtles
    [
        set j 0
        foreach sort turtles
        [
            ifelse (i = j) or (abs (i - j) = 1 ) or (abs (i - j) = ( number_of_agents - 1 ) )
            [ask turtle i [ set liste_conf_epist lput ( 1 / 3 ) liste_conf_epist] ]
            [ask turtle i [ set liste_conf_epist lput 0 liste_conf_epist] ]
            set j (j + 1)
        ]
        set i (i + 1)
    ]
  ]
  if modeles_relations = "observer"
  [
    foreach sort turtles
    [
        set j 0
        foreach sort turtles
        [
            ifelse i = j
            [
              ifelse i = 0
              [ask turtle i [ set liste_conf_epist lput 0 liste_conf_epist] ]
              [ask turtle i [ set liste_conf_epist lput 1 liste_conf_epist] ]
            ]
            [
              ifelse i = 0
              [ask turtle i [ set liste_conf_epist lput (1 / (number_of_agents - 1)) liste_conf_epist] ]
              [ask turtle i [ set liste_conf_epist lput 0 liste_conf_epist] ]
            ]
            set j (j + 1)
        ]
        set i (i + 1)
    ]
  ]
  if modeles_relations = "random"
  [
    foreach sort turtles
    [
        let som 0
        set j 0
        foreach sort turtles
        [
          ifelse (random 100 / 100) < random_link_probability
          [
            let rand_number (random 100 / 100)
            ask turtle i [ set liste_conf_epist lput rand_number liste_conf_epist]
            set som (som + rand_number)
          ]
          [
            ask turtle i [ set liste_conf_epist lput 0 liste_conf_epist]
          ]
          set j (j + 1)
        ]
        let k 0
        ask turtle i
        [
          foreach liste_conf_epist
          [ [??1] ->
            ifelse som > 0
            [
              set liste_conf_epist (replace-item k liste_conf_epist (??1 / som))
            ]
            [
              set liste_conf_epist (replace-item i liste_conf_epist 1)
            ]
            set k (k + 1)

          ]
        ]
        set i (i + 1)
    ]
  ]
end

;pour la matrice de confiance et les les données topologiques des tortues
to set-up-matrice

set matrice []
  let i 0
  foreach sort turtles
  [ [?1] ->
    ask ?1 [set matrice lput liste_conf_epist matrice]
  ]

set matrix matrix:from-row-list matrice

let j 0                                    ;ici la boucle pour fixer le indegree = la somme des poids des liens de confiance pointant sur chaque tortue
  while [j != number_of_agents]
  [let temp matrix:get-column matrix j
    ask turtle j [set indegree sum temp ]

  set j (j + 1)
  ]

  let k 0                                    ;ici la boucle pour fixer le nb_out_neighboors = le nombre d'agents directement accessibles à une totrtue donnée
  while [k != number_of_agents]
  [let l 0
    let temp2 0
    while [l != number_of_agents]
   [ ask turtle k [set temp2 ceiling (item l (item k matrice) ) + temp2   ]
    set l ( l + 1)
    ]
   ask turtle k [set nb_out_neighboors temp2]
  set k (k + 1)
  ]

 end

;où alternativement avec une boucle explicite (pour construire la pré-matrice comme liste de listes
;to set-up-matrice
;set matrice []
; let i 0
;  while [i != number_of_agents]
;  [
;    ask turtle i [set matrice lput liste_conf_epist matrice]
;
;  set i (i + 1)
;  ]
; end



;modelise les relations entre les agents par des flèches
to add_arrow
  let i 0
  let j 0
  let th 0

  foreach sort turtles
  [
    set j 0
    foreach sort turtles
    [
      ask turtle i
      [
          set th (item j liste_conf_epist)
          if th != 0 and i != j
          [ create-link-to turtle j [set thickness th / 4 ] ]
      ]
      set j (j + 1)
    ]
    set i (i + 1)
  ]
  ask links [ set shape "my_link" ]
end



to go
  if ticks >= number-ticks [ stop ]
  update_ind_nat
  update_estime
  update_croyance
  update_perf
  determine_couple
  tick
end



;mise à jour des croyances
to update_croyance
  let somme 0
  let temp 0
  let i 0
  let j 0
  let lst_croy_tmp []

  ifelse Nature_update
  [

  foreach sort turtles
 [
    set j 0
    set somme 0
    foreach sort turtles
    [
      ifelse i = j
      [
          ask turtle i [set somme (somme + ( (item i liste_conf_epist) * (last liste_estime_direct) ) ) ]
      ]
      [
          ask turtle i [ set temp (item j liste_conf_epist)]
          ask turtle j [ set somme ( somme + (temp * (last liste_croyance) ) ) ]
      ]
      set j (j + 1)
    ]
    set lst_croy_tmp lput somme lst_croy_tmp
    set i (i + 1)
  ]
  ]

[

  foreach sort turtles
 [
    set j 0
    set somme 0
    foreach sort turtles
    [
      ifelse i = j
      [
          ask turtle i [set somme (somme + ( (item i liste_conf_epist) * (last liste_croyance) ) ) ]
      ]
      [
          ask turtle i [ set temp (item j liste_conf_epist)]
          ask turtle j [ set somme ( somme + (temp * (last liste_croyance) ) ) ]
      ]
      set j (j + 1)
    ]
    set lst_croy_tmp lput somme lst_croy_tmp
    set i (i + 1)
  ]
  ]


  set i 0
  foreach sort turtles
  [ [?1] ->
    ask ?1 [
      set liste_croyance lput ( item i lst_croy_tmp) liste_croyance
    ]
    set i ( i + 1)
  ]
end




;mise à jour des performances des agents
to update_perf
  let temp 0
  let somme 0
  let somme_expert 0
  let somme_layman 0
  let nb_exp 0
  let nb_lay 0

  foreach sort turtles
  [ [?1] ->
    ask ?1
    [
      set temp ( ((last liste_croyance) - parametre_a_estimer) * ((last liste_croyance) - parametre_a_estimer) )
      set liste_performence lput temp liste_performence
      set somme (somme + temp)
      ifelse expert
      [ set somme_expert (somme_expert + temp)
        set nb_exp (nb_exp + 1)]
      [ set somme_layman (somme_layman + temp)
        set nb_lay (nb_lay + 1)]
    ]
  ]
  set list_perf_glob lput (somme / number_of_agents) list_perf_glob
  if nb_exp > 0
  [ set list_perf_expert lput (somme_expert / nb_exp) list_perf_expert ]
  if nb_lay > 0
  [ set list_perf_lay lput (somme_layman / nb_lay) list_perf_lay ]
end




;mise à jour de l'indice naturel des agents
to update_ind_nat
  let indice -1
  ask turtles
  [
      ifelse expert
      [
        while [ indice < 0 or indice > 1 ]
        [
          set indice random-normal parametre_a_estimer ecart_type_expert
        ]
        set liste_ind_nature lput indice liste_ind_nature
        set indice -1
      ]
      [
        while [ indice < 0 or indice > 1 ]
        [
          set indice random-normal parametre_a_estimer ecart_type_laymen
        ]
        set liste_ind_nature lput indice liste_ind_nature
      ]
  ]
end




;mise à jour de l'estimation des agents
to update_estime
  foreach sort turtles
  [ [?1] ->
    ask ?1
    [
      set liste_estime_direct lput ( (sum [ liste_ind_nature ] of ?1) / (length liste_ind_nature) ) liste_estime_direct
    ]
  ]
end





;artifice pour reporter dans le behaviour space le couple (dernière perf ; nb_out_neighboors)
 to determine_couple
      let m 0                                    ; artifice pour pouvoir reporter facilement le couple (performance ; nb_out_neighboors) dans le bahaviour space
  while [m != number_of_agents]

   [ ask turtle m [set couple []]
     ask turtle m [set couple lput last liste_performence couple]
     ask turtle m [set couple lput nb_out_neighboors couple]
  set m (m + 1)
  ]
 end


to-report impact
  let val 0
let val2 0
if ticks > 0
[
foreach sort turtles [ [?1] ->
    set val [ last liste_estime_direct ] of ?1
    set val val - parametre_a_estimer
    set val val * val
    set val2 [ last liste_performence ] of ?1
    set val2 val - val2
    report val2
 ]
]
end
@#$#@#$#@
GRAPHICS-WINDOW
274
54
656
437
-1
-1
9.122
1
10
1
1
1
0
0
0
1
-20
20
-20
20
1
1
1
ticks
30.0

SLIDER
10
13
182
46
parametre_a_estimer
parametre_a_estimer
0
1
0.64
0.01
1
NIL
HORIZONTAL

SLIDER
10
46
182
79
proportion_expert
proportion_expert
0
1
0.01
0.01
1
NIL
HORIZONTAL

SWITCH
10
79
182
112
agent1_expert
agent1_expert
1
1
-1000

SLIDER
10
111
182
144
ecart_type_expert
ecart_type_expert
0
1
0.13
0.01
1
NIL
HORIZONTAL

SLIDER
10
143
182
176
ecart_type_laymen
ecart_type_laymen
0
1
0.22
0.01
1
NIL
HORIZONTAL

CHOOSER
10
176
182
221
modeles_relations
modeles_relations
"master" "observer" "circle" "random"
3

BUTTON
20
384
83
417
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

BUTTON
101
384
164
417
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
10
221
182
254
seed-random
seed-random
0
100
35.0
1
1
NIL
HORIZONTAL

SLIDER
10
254
182
287
number-ticks
number-ticks
0
100
41.0
1
1
NIL
HORIZONTAL

OUTPUT
226
460
660
502
11

TEXTBOX
7
426
205
482
agent1 particulier = le cercle du milieu\nrouge -> layman\nbleu -> expert
11
126.0
0

PLOT
660
533
1098
750
Evolution du score moyen global (vert), du score moyen expert (bleu), et du score moyen non-expert (rouge))
NIL
d moyen par sous groupe
0.0
10.0
0.0
0.05
true
true
"create-temporary-plot-pen (word \"collec\")\nset-plot-pen-color green\ncreate-temporary-plot-pen (word \"expert\")\nset-plot-pen-color blue\ncreate-temporary-plot-pen (word \"laymen\")\nset-plot-pen-color red" "if (length list_perf_glob) > 0\n[\n   set-current-plot-pen (word \"collec\")\n   plot last list_perf_glob\n]\nif (length list_perf_expert) > 0\n[\n  set-current-plot-pen (word \"expert\")\n  plot last list_perf_expert\n]\nif (length list_perf_lay) > 0\n[\n  set-current-plot-pen (word \"laymen\")\n  plot last list_perf_lay\n]"
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
661
359
1095
528
Evolution des Scores individuels : Evolution de la distance [d] de la croyance [c] à la valeur réel du parametre [t]  
NIL
d = [(c - t)^2] 
0.0
10.0
0.0
0.1
true
false
"let expe true\nforeach sort turtles [ [?1] ->\n  ask ?1 [set expe expert]\n  create-temporary-plot-pen (word \"p\"?1)\n  ifelse expe\n  [ set-plot-pen-color ( random 8 + 91 )]\n  [ set-plot-pen-color ( random 8 + 11 )]\n ]" "foreach sort turtles [ [?1] ->\n  ask ?1\n  [\n    if length liste_performence > 0\n    [\n      set-current-plot-pen (word \"p\"?1)\n      plot [ last liste_performence ] of ?1\n    ]\n  ]\n ]"
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
661
16
1093
353
évolution des croyances
NIL
Estimation du paramètre par les agents
0.0
10.0
0.0
1.0
true
true
"let expe true\nforeach sort turtles [ [?1] ->\n  ask ?1 [set expe expert]\n  create-temporary-plot-pen (word \"p\"?1)\n  ifelse expe\n  [ set-plot-pen-color ( random 8 + 91 )]\n  [ set-plot-pen-color ( random 8 + 11 )]\n ]" "if ticks > 1 [\nforeach sort turtles [ [?1] ->\n    set-current-plot-pen (word \"p\"?1)\n    plot [ last liste_croyance ] of ?1\n ]\n]"
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
47
508
655
749
L'impact de l'information indirecte sur la qualité de l'estimation
NIL
NIL
0.0
10.0
0.0
0.01
true
true
"let expe true\nforeach sort turtles [ [?1] ->\n  ask ?1 [set expe expert]\n  create-temporary-plot-pen (word \"p\"?1)\n  ifelse expe\n  [ set-plot-pen-color ( random 8 + 91 )]\n  [ set-plot-pen-color ( random 8 + 11 )]\n ]" "let val 0\nlet val2 0\nif ticks > 0\n[\nforeach sort turtles [ [?1] ->\n    set val [ last liste_estime_direct ] of ?1\n    set val val - parametre_a_estimer\n    set val val * val\n    set val2 [ last liste_performence ] of ?1\n    set val2 val - val2\n    set-current-plot-pen (word \"p\"?1)\n    plot val2\n ]\n]"
PENS
"default" 1.0 0 -16777216 true "" ""
"0-line" 1.0 0 -16777216 true "set-plot-pen-color 0" "plot 0"

SLIDER
10
346
182
379
random_link_probability
random_link_probability
0
1
0.19
0.01
1
NIL
HORIZONTAL

INPUTBOX
10
287
181
347
number_of_agents
10.0
1
0
Number

SWITCH
183
14
319
47
Nature_update
Nature_update
0
1
-1000

@#$#@#$#@
## AUTHORS

DENIS Alexandre (ISIMA) & CALIME Adrien (ISIMA) sous la direction de Henri Galinon (UCA, PHIER)

## TITLE

Network of truth-seeking agents : when topology trumps ability

## WHAT IS IT?

 This model allows to study how the existence and structure of relations of epistemic trust in a group of truth-seeking agents might affect the epistemic performance of the agents taken individually and as a group. At each step, each agent independently receive from nature a noisy signal pointing to the real value of a certain parameter in [0,1], and balance this information with indirect information about the parameter he obtains by observing the beliefs of his trusted fellows. Agents are taken to be boundedly rational and update their belief following a version of DeGroot model of update (also known as Lehrer-Wagner rule).
 The agents' abilities to extract information from nature can be differentiated between expert abilities and laymen abilities. These abilities can in turn be varied in the model, in the form of a variation of the standard deviation of the normal law followed by the random signals that experts and layman respectively receive from nature as indication pointing to the real value of the parameter.
The structures of epistemic trust can be choosen amongst 4 possibilities : a so-called "master" structure, an "observer" structure, an "circle" structure and a form of random structure which can be used for control purposes in experiments.
Epistemic performance is measured as the distance of the believed value to the true value of the parameter.

## HOW IT WORKS

In order to observe effectively the evolution of agents, many rules has been created :
- All agents have a specific type which are expert or laymen. An expert better has a better view of the parameter to estimate.
- An agent will receive at each instant T a natural index which follows a random normal low with the parameter to estimate as average and a specific value of the type of agents as standard deviation.
- All agents have a trust toward other agents concerning the value to determine. This trust depends on the style of a group. Four styles has been implemented : 
    ->Master : There is one master who listens all the other agents. An other agent believes himselves at 50% and the master at 50%.
    ->Circle : All agents are the same. One agent believes himself at 33% and two 
neighbors at 33% each one. 
    ->Observer : There is one observer who listens all the other agents. An other agent believes himselves at 100%.
    ->Random : All agents have a belief created randomly.
- At each instant T, an agent has an estimation of the value to determine calculating with natural indexes he received.
- At each instant T, an agent calculates his belief with the help of the calculated beliefs of the other agents and his own estimation of the value.
- All agents have a performance which is calculated by comparing his belief and the value to determine.
- Other kinds of performance have been implemented as the global performance, the laymen performance and the expert performance.

## HOW TO USE IT

There are many parameters to use in this project for the use of it :
- The value to determine which is a number between 0 and 1
- The percentage of expert in the model to simulate
- An other parameter allows users to force the first agent to be an expert or a layman
- The standard deviation for an expert
- The standard deviation for a layman
- The type of relation the user wants (master, observer, circle, random)
- The random seed which allows the programm to be reproducible
- The number of ticks represents the time to observe
- The number of agents can be modified
- The probability to create a link between two agents in the random model

## THINGS TO NOTICE

The main things to notice are the four monitors in the main screen of the program. It informs users of the performance of the agents. We can see performances that show if we are near to the value to estimate (if the performance equals 0 the belief equals the value to determine). We can also notice the value of the beliefs for each agents over time.

## THINGS TO TRY

You can try what you want by moving all parameters available on the main sceen.

## EXTENDING THE MODEL

A possible extension is to create link between agents which can be changed during the simulation. An other extension is to create a list of parameters to estimate.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.3.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>[ last liste_croyance ] of turtle 0</metric>
    <metric>[ last liste_croyance ] of turtle 1</metric>
    <metric>[ last liste_croyance ] of turtle 2</metric>
    <metric>[ last liste_croyance ] of turtle 3</metric>
    <metric>[ last liste_croyance ] of turtle 4</metric>
    <metric>[ last liste_croyance ] of turtle 5</metric>
    <metric>[ last liste_croyance ] of turtle 6</metric>
    <metric>[ last liste_croyance ] of turtle 7</metric>
    <metric>[ last liste_croyance ] of turtle 8</metric>
    <metric>[ last liste_croyance ] of turtle 9</metric>
    <metric>[ last liste_performence ] of turtle 0</metric>
    <metric>[ last liste_performence ] of turtle 1</metric>
    <metric>[ last liste_performence ] of turtle 2</metric>
    <metric>[ last liste_performence ] of turtle 3</metric>
    <metric>[ last liste_performence ] of turtle 4</metric>
    <metric>[ last liste_performence ] of turtle 5</metric>
    <metric>[ last liste_performence ] of turtle 6</metric>
    <metric>[ last liste_performence ] of turtle 7</metric>
    <metric>[ last liste_performence ] of turtle 8</metric>
    <metric>[ last liste_performence ] of turtle 9</metric>
    <metric>[ nb_out_neighboors ] of turtle 0</metric>
    <metric>[ nb_out_neighboors ] of turtle 1</metric>
    <metric>[ nb_out_neighboors ] of turtle 2</metric>
    <metric>[ nb_out_neighboors ] of turtle 3</metric>
    <metric>[ nb_out_neighboors ] of turtle 4</metric>
    <metric>[ nb_out_neighboors ] of turtle 5</metric>
    <metric>[ nb_out_neighboors ] of turtle 6</metric>
    <metric>[ nb_out_neighboors ] of turtle 7</metric>
    <metric>[ nb_out_neighboors ] of turtle 8</metric>
    <metric>[ nb_out_neighboors ] of turtle 9</metric>
    <enumeratedValueSet variable="agent1_expert">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="parametre_a_estimer">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion_expert">
      <value value="0.11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-ticks">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_of_agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed-random">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ecart_type_laymen">
      <value value="0.85"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ecart_type_expert">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random_link_probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="modeles_relations">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_correpertoutdegreeRandom" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>[couple] of turtles</metric>
    <enumeratedValueSet variable="agent1_expert">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="parametre_a_estimer">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion_expert">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-ticks">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_of_agents">
      <value value="100"/>
    </enumeratedValueSet>
    <steppedValueSet variable="seed-random" first="1" step="1" last="99"/>
    <enumeratedValueSet variable="ecart_type_laymen">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ecart_type_expert">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random_link_probability">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="modeles_relations">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_impact of indirect information_Master" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>[ impact ] of turtles</metric>
    <steppedValueSet variable="seed-random" first="1" step="1" last="99"/>
    <enumeratedValueSet variable="ecart_type_laymen">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ecart_type_expert">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random_link_probability">
      <value value="0.24"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_of_agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="modeles_relations">
      <value value="&quot;master&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="agent1_expert">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="parametre_a_estimer">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-ticks">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion_expert">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

my_link
1.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
